#!/bin/sh
# Print error message
error() {
    echo "There were errors..."
}

# Print completed message
jobCompleted() {
    echo "Done!"
}

# Compile the java code
compileJava() {
    echo "Compiling java code..."
    cd java-src
    javac -Xlint:unchecked -cp ../lib/rarx.jar *.java
    JAVAC_EXIT_CODE=$?
    cd ..
    return $JAVAC_EXIT_CODE
}

# Compile the C code
compileC_i686() {
    echo "Compiling C code (i686)..."
    # -I/System/Library/Frameworks/JavaVM.framework/Headers
    gcc -b i686-apple-darwin8 -Wall -I/System/Library/Frameworks/JavaVM.framework/Headers native-src/rarfs_fuse.c -o rarfs.out.i686 -lfuse -framework JavaVM -D__FreeBSD__=10 -D_FILE_OFFSET_BITS=64 -DFUSE_USE_VERSION=25
    return $?
}

compileC_ppc() {
    echo "Compiling C code (ppc)..."
    # -I/System/Library/Frameworks/JavaVM.framework/Headers
    gcc -b powerpc-apple-darwin8 -Wall -I/System/Library/Frameworks/JavaVM.framework/Headers native-src/rarfs_fuse.c -o rarfs.out.ppc -lfuse -framework JavaVM -D__FreeBSD__=10 -D_FILE_OFFSET_BITS=64 -DFUSE_USE_VERSION=25
    return $?
}

createub() {
    echo "Creating universal binary..."
    lipo -create -arch i386 rarfs.out.i686 -arch ppc rarfs.out.ppc -output rarfs_fuse
    return $?
}

cleanup() {
    echo "Cleaning up..."
    rm rarfs.out.i686 rarfs.out.ppc
    return $?
}

main() {
    compileJava
    if [ "$?" == 0 ]; then
	compileC_i686
	if [ "$?" == 0 ]; then
	    compileC_ppc
	    if [ "$?" == 0 ]; then
		createub
		if [ "$?" == 0 ]; then
		    cleanup
		    if [ "$?" == 0 ]; then
			jobCompleted
		    else
			error
		    fi
		else
		    error
		fi
	    else
		error
	    fi
	else
	    error
	fi
    else
	error
    fi
}

# entry point
main